## Changelog version 1.3.2 - 1.4.0

This changelog was created automatically using git log command. 

- 2019-04-22 Deleted old file CHANGELOG.rst (changelogs will be stored in directory changelog and will start from last release 1.3.2)
- 2019-04-18 Included package data in local_topo_paths into MANIFEST.in for source distributions; Updated docs in atmosphere.py; ran installation and all tests in isolated env using geonum_env_py3.yml (all OK); set version to 1.4.0
- 2019-04-18 Updated api.rst file for documentation website
- 2019-04-18 Worked on docs
- 2019-04-18 Updated tests
- 2019-04-18 Updated relative imports in other modules and worked on docs
- 2019-04-18 API refactor: Moved class ElevationProfile from processing.py into new module elevationprofile.py; worked on docs
- 2019-04-18 New module exceptions.py (contains exceptions previously defined in topodata.py module)
- 2019-04-18 Major refactor: seperated content of topodata.py module into 3 modules -> topoaccessbase.py, topodataaccess.py and topodata.py for more code granularity; worked on docs
- 2019-04-18 Updated import of TopoDataAccess class in example script 5
- 2019-04-18 Added pytest and basemap to geonum_env_py3.yml file and moved srtm.py to pip since conda tried to install py27 version
- 2019-04-18 Updated imports in scripts after recent API refactor (base.py -> geopoint.py and geovector3d.py)
- 2019-04-18 Updated version
- 2019-04-18 API refactor: moved GeoPoint and GeoVector3D classes from base.py into 2 new separate submodules (geopoint.py and geovector3d.py), cleaned up some imports
- 2019-04-18 Renamed geonum_env.yml -> geonum_env_py3.yml and added python 3 dependency since installation in python 2.7 failed (and is not further recommended to be used anyways)
- 2019-04-13 Added project root to install in readthedocs.yml
- 2019-04-13 Minor reformatting
- 2019-04-13 Added RTD theme to docs requirements
- 2019-04-13 fixed minor bug
- 2019-04-13 Updated readthedocs.yml
- 2019-04-13 Updated readthedocs.yml
- 2019-04-13 Resolved merge conflict in requirements.txt
- 2019-04-13 updated requirements.txt and added readthedocs.yml and conda environment file geonum_env.yml
- 2019-03-01 Update requirements.txt
- 2019-03-01 Update requirements.txt
- 2019-03-01 Updated README
- 2019-03-01 Added python version 3.7-dev to .travis.yml
- 2019-03-01 Updated travis.yml
- 2019-03-01 Updated travis.yml
- 2019-03-01 Updated travis.yml (removed test for osx and included windows)
- 2019-03-01 Added multiple OS testing (linux and windows) in travis.yml
- 2019-02-21 Update README.rst
- 2019-02-21 Update README.rst
- 2019-02-21 Merge branch 'master' of https://github.com/jgliss/geonum
- 2019-02-21 Removed display of class __init__ methods in docs
- 2019-02-21 Update README.rst
- 2019-02-21 Update README.rst
- 2019-02-21 Update README.rst
- 2019-02-21 Update README.rst
- 2019-02-21 Merge branch 'master' of https://github.com/jgliss/geonum
- 2019-02-21 Removed all dependencies of LatLon library; now LatLon23 is strict requirement
- 2019-02-21 Update README.rst
- 2019-02-21 Update .travis.yml
- 2019-02-21 Update .travis.yml
- 2019-02-21 Update .travis.yml
- 2019-02-21 Update README.rst
- 2019-02-21 Rename travis.yml to .travis.yml
- 2019-02-21 Added first version of travis.yml file
- 2019-02-21 Updated pytest version req in test-requirements.txt
- 2019-02-21 Removed LatLon and added netcdf4 from requirements.txt
- 2019-02-21 Updated numpy imports
- 2019-02-21 Largely simplified and minimalised factory class TopoAccess and cleaned up some docs
- 2019-02-21 Added some tests
- 2019-02-20 Updated version
- 2019-02-20 Merge branch 'master' of https://github.com/jgliss/geonum
- 2019-02-20 Instantiation of topography data access classes in GeoPoint and GeoSetup are now dynamic via decorator attributes
- 2019-02-17 Changed type of Exception raise if module is missing
- 2019-02-15 updated version
- 2019-02-15 Added more unit tests
- 2019-02-15 Added more options for retrieval of elevation profiles
- 2019-02-15 Added more options for computation of elevation profiles
- 2019-02-15 Some minor updates in mapping.py, new global variable TOPO_INFO_FILE in __init__
- 2019-02-15 Added two helper methods for search of local topography datasets
- 2019-02-15 Reviewed and cleaned up reading of topographic data and increased user-friendliness; added some new featurs to TopoData class
- 2019-02-11 Minor changes in code documentation and library initialisation
- 2019-02-11 Updated parts of the docstrings
- 2019-02-04 Updated version
- 2019-02-04 GeoPoint altitude attribute is set to 0 now  is auto_topo_access is False (before it was set to None, and then some arithmetic operations did not work
- 2019-02-04 Added .pytest_cache directory to gitignore
- 2018-12-27 Merge branch 'johannjacobsohn-master'
- 2018-11-29 fix deepcopy issue in pyplis, needs unit tests
- 2018-11-27 fix pytest version to 3
- 2018-11-27 add scripts to tox
- 2018-11-22 Merge branch 'master' of https://github.com/jgliss/geonum
- 2018-09-14 Updated version